"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.encode = void 0;
const rdf_js_1 = require("./rdf.js");
const mod_js_1 = require("./namespaces/mod.js");
const encode = (node, schema, context, variableInitCounter = 0) => {
    return Encoder.encode(node, schema, context, variableInitCounter);
};
exports.encode = encode;
class Encoder {
    constructor(context, variableInitCounter) {
        Object.defineProperty(this, "context", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "df", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: new rdf_js_1.DataFactory({
                blankNodePrefix: "b",
            })
        });
        Object.defineProperty(this, "variableCounter", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "output", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: []
        });
        this.context = context;
        this.variableCounter = variableInitCounter;
    }
    static encode(node, schema, context, variableInitCounter) {
        return new Encoder(context, variableInitCounter).encode(node, schema);
    }
    encode(node, schema) {
        const nodeId = this.getNodeId(node);
        this.encodeNode(node, schema, nodeId);
        return this.output;
    }
    push(s, p, o) {
        this.output.push(this.df.quad(s, p, o));
    }
    getNodeId(node) {
        return node.$id
            ? this.df.namedNode(node.$id)
            : this.df.blankNode();
    }
    getNodeTypes(node) {
        if (Array.isArray(node.$type)) {
            return node.$type;
        }
        return node.$type ? [node.$type] : [];
    }
    encodeNode(node, schema, nodeId) {
        this.encodeNodeType(node, schema["@type"], nodeId);
        Object.keys(schema).forEach((key) => {
            if (key === "@type") {
                return;
            }
            this.encodeNodeProperty(node[key], schema[key], nodeId);
        });
    }
    encodeNodeType(node, requiredTypes, nodeId) {
        const finalTypes = new Set([...this.getNodeTypes(node), ...requiredTypes]);
        finalTypes.forEach((type) => {
            this.push(nodeId, this.df.namedNode(mod_js_1.rdf.type), this.df.namedNode(type));
        });
    }
    encodeNodeProperty(value, property, nodeId) {
        if (value === undefined) {
            return;
        }
        const propertyId = this.df.namedNode(property["@id"]);
        if (value === null) {
            // TODO
            this.push(nodeId, propertyId, this.df.variable(`v${this.variableCounter++}`));
            return;
        }
        if (property["@multilang"]) {
            Object.keys(value).forEach((language) => {
                const languageValue = Array.isArray(value[language])
                    ? value[language]
                    : [value[language]];
                languageValue.forEach((singleValue) => {
                    this.push(nodeId, propertyId, this.df.literal(singleValue, language.length > 0 ? language : undefined));
                });
            });
            return;
        }
        const values = Array.isArray(value) ? value : [value];
        values.forEach((val) => {
            if (property["@context"]) {
                const subNodeId = this.getNodeId(val);
                this.encodeNode(val, property["@context"], subNodeId);
                this.push(nodeId, propertyId, subNodeId);
                return;
            }
            const propertyType = property["@type"] ? property["@type"] : mod_js_1.xsd.string;
            if (typeof val === "string" && this.context.language) {
                if (propertyType === mod_js_1.xsd.string || propertyType === mod_js_1.rdf.langString) {
                    this.push(nodeId, propertyId, this.df.literal(val, this.context.language));
                    return;
                }
            }
            const rdfValue = (0, rdf_js_1.toRdf)(val, {
                datatype: this.df.namedNode(propertyType),
            });
            this.push(nodeId, propertyId, rdfValue);
        });
    }
}
