"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getSchemaProperties = exports.expandSchema = void 0;
const mod_js_1 = require("../namespaces/mod.js");
const expandSchema = (schemaPrototype) => {
    const expandArray = (stringOrStrings) => {
        return Array.isArray(stringOrStrings) ? stringOrStrings : [stringOrStrings];
    };
    const expandSchemaProperty = (stringOrProperty) => {
        if (typeof stringOrProperty === "string") {
            return {
                "@id": stringOrProperty,
                "@type": mod_js_1.xsd.string,
            };
        }
        const property = stringOrProperty;
        if (!property["@id"]) {
            throw new Error(`Invalid schema, "@id" key for property missing`);
        }
        const validKeys = [
            "@context",
            "@id",
            "@type",
            "@array",
            "@optional",
            "@multilang",
        ];
        const baseProperty = {
            "@id": "",
        };
        const expandedProperty = Object.keys(property).reduce((acc, key) => {
            if (key === "@context") {
                acc[key] = (0, exports.expandSchema)(property[key]);
            }
            else if (validKeys.includes(key)) {
                acc[key] = property[key];
            }
            return acc;
        }, baseProperty);
        if (!baseProperty["@type"] && !baseProperty["@context"]) {
            baseProperty["@type"] = mod_js_1.xsd.string;
        }
        return expandedProperty;
    };
    const baseSchema = {
        "@type": [],
    };
    return Object.keys(schemaPrototype).reduce((acc, key) => {
        if (key === "@type") {
            acc[key] = expandArray(schemaPrototype[key]);
        }
        else {
            acc[key] = expandSchemaProperty(schemaPrototype[key]);
        }
        return acc;
    }, baseSchema);
};
exports.expandSchema = expandSchema;
const getSchemaProperties = (schema) => {
    const { "@type": _ommitedType, ...properties } = schema;
    return properties;
};
exports.getSchemaProperties = getSchemaProperties;
