import type { Bindings, BlankNode, Literal, NamedNode, Quad, Term, Variable } from "rdf-js";
export type { Bindings, BlankNode, Literal, NamedNode, Quad, Term, Variable };
import type * as RDF from "rdf-js";
export type { RDF };
export { fromRdf, toRdf } from "rdf-literal";
import { DataFactory } from "rdf-data-factory";
export { DataFactory };
import { BindingsFactory as ComunicaBindingsFactory } from "@comunica/bindings-factory";
import type { IDataSource, IQueryContextCommon } from "@comunica/types";
export declare type LDkitContext = {
    graph?: string;
    language?: string;
};
export declare type Context = LDkitContext & RDF.QueryStringContext & RDF.QuerySourceContext<IDataSource> & IQueryContextCommon;
export declare type IQueryEngine = RDF.StringSparqlQueryable<RDF.SparqlResultSupport, Context>;
export declare type Iri = string;
export declare type Node = Map<Iri, Term[]>;
export declare type Graph = Map<Iri, Node>;
export declare const quadsToGraph: (quads: Quad[]) => Graph;
export declare namespace RDFJSON {
    type Term = {
        type: "uri" | "literal" | "bnode";
        value: string;
        "xml:lang"?: string;
        datatype?: string;
    };
    type Bindings = Record<string, Term>;
    type SparqlResultsJsonFormat = {
        head: {
            vars?: string[];
        };
        results?: {
            bindings: Bindings[];
        };
        boolean?: boolean;
    };
    type RdfJsonFormat = Record<Iri, Record<Iri, Term[]>>;
    interface TermFactory {
        fromJson(jsonTerm: Term): RDF.Term;
    }
    interface BindingsFactory {
        fromJson(jsonBindings: Bindings): RDF.Bindings;
    }
    interface QuadFactory {
        fromJson(jsonRdf: [Iri, Iri, Term]): RDF.Quad;
    }
}
export declare class TermFactory implements RDFJSON.TermFactory {
    protected readonly dataFactory: RDF.DataFactory;
    constructor(dataFactory?: RDF.DataFactory);
    fromJson(jsonTerm: RDFJSON.Term): BlankNode | Literal | NamedNode<string>;
}
export declare class BindingsFactory extends ComunicaBindingsFactory implements RDFJSON.BindingsFactory {
    protected readonly localDataFactory: RDF.DataFactory;
    protected readonly termFactory: RDFJSON.TermFactory;
    constructor(dataFactory?: RDF.DataFactory, termFactory?: RDFJSON.TermFactory);
    fromJson(jsonBindings: RDFJSON.Bindings): Bindings;
}
export declare class QuadFactory implements RDFJSON.QuadFactory {
    protected readonly dataFactory: RDF.DataFactory;
    protected readonly termFactory: RDFJSON.TermFactory;
    constructor(dataFactory?: RDF.DataFactory, termFactory?: RDFJSON.TermFactory);
    fromJson(jsonRdf: [Iri, Iri, RDFJSON.Term]): Quad;
}
