import type { Context, IQueryEngine, Iri, RDF } from "../rdf.js";
import { type SchemaInterface, type SchemaInterfaceIdentity, type SchemaPrototype } from "../schema/mod.js";
import type { Entity } from "./types.js";
export declare const createResource: <T extends SchemaPrototype>(spec: T, context?: Context, engine?: IQueryEngine) => Resource<T, SchemaInterface<T>>;
export declare class Resource<S extends SchemaPrototype, I = SchemaInterface<S>> {
    private readonly schema;
    private readonly context;
    private readonly engine;
    private readonly queryBuilder;
    constructor(schema: S, context?: Context, engine?: IQueryEngine);
    private decode;
    count(): Promise<number>;
    query(sparqlConstructQuery: string): Promise<I[]>;
    find(where?: string | RDF.Quad[], limit?: number): Promise<I[]>;
    findByIri(iri: Iri): Promise<I | undefined>;
    findByIris(iris: Iri[]): Promise<I[]>;
    private updateQuery;
    insert(...entities: Entity<I>[]): Promise<void>;
    insertData(...quads: RDF.Quad[]): Promise<void>;
    update(...entities: Entity<I>[]): Promise<void>;
    delete(...identities: SchemaInterfaceIdentity[] | Iri[]): Promise<void>;
    deleteData(...quads: RDF.Quad[]): Promise<void>;
}
