import type { SupportedDataTypes } from "./data_types.js";
import type { SchemaPrototype, PropertyPrototype } from "./schema.js";
declare type IsOptional<Property extends PropertyPrototype> = Property extends {
    "@optional": true;
} ? true : false;
declare type IsArray<Property extends PropertyPrototype> = Property extends {
    "@array": true;
} ? true : false;
declare type IsMultilang<Property extends PropertyPrototype> = Property extends {
    "@multilang": true;
} ? true : false;
declare type ValidPropertyDefinition = PropertyPrototype | string;
declare type ConvertPropertyType<T extends PropertyPrototype> = T extends {
    "@context": SchemaPrototype;
} ? SchemaInterface<T["@context"]> : T extends {
    "@type": any;
} ? T["@type"] extends keyof SupportedDataTypes ? SupportedDataTypes[T["@type"]] : never : string;
declare type ConvertPropertyOptional<T extends PropertyPrototype> = IsOptional<T> extends true ? ConvertPropertyType<T> | undefined : ConvertPropertyType<T>;
declare type ConvertPropertyArray<T extends PropertyPrototype> = IsArray<T> extends true ? ConvertPropertyType<T>[] : ConvertPropertyOptional<T>;
declare type ConvertPropertyMultilang<T extends PropertyPrototype> = IsMultilang<T> extends true ? IsArray<T> extends true ? Record<string, ConvertPropertyType<T>[]> : Record<string, ConvertPropertyType<T>> : ConvertPropertyArray<T>;
declare type ConvertPropertyObject<T extends PropertyPrototype> = ConvertPropertyMultilang<T>;
declare type ConvertProperty<T extends ValidPropertyDefinition> = T extends PropertyPrototype ? ConvertPropertyObject<T> : string;
export declare type SchemaInterfaceIdentity = {
    $id: string;
};
export declare type SchemaInterfaceType = {
    $type: string[];
};
export declare type SchemaInterface<T extends SchemaPrototype> = {
    [X in Exclude<keyof T, "@type">]: T[X] extends ValidPropertyDefinition ? ConvertProperty<T[X]> : never;
} & SchemaInterfaceIdentity & SchemaInterfaceType;
export {};
